@@ -58,9 +58,12 @@ use v5.40;
 #
 
 
-our $VERSION = '0.03';
+our $VERSION = '0.07';
 
 use Daje::Database::Model::ToolsProjects;
+use Daje::Database::Helper::TreeList;
+use Daje::Database::View::VToolsProjects;
+use Daje::Database::View::VToolsVersion;
 
 sub register ($self, $app, $config) {
     $app->log->debug("Daje::Plugin::Tools::register start");
@@ -69,10 +72,26 @@ sub register ($self, $app, $config) {
         tools_projects => sub {
             state  $tools_projects = Daje::Database::Model::ToolsProjects->new(db => shift->pg->db)
         });
+    $app->helper(
+        tools_helper_treelist => sub {
+            state  $tools_helper_treelist = Daje::Database::Helper::TreeList->new(db => shift->pg->db)
+        });
 
+    $app->helper(
+        v_tools_projects => sub {
+            state  $v_tools_projects = Daje::Database::View::VToolsProjects->new(db => shift->pg->db)
+        });
+    $app->helper(
+        v_tools_versions => sub {
+            state  $v_tools_versions = Daje::Database::View::VToolsVersion->new(db => shift->pg->db)
+        });
+
+
+    ;
     my $r = $app->routes;
-    $r->get('/tools/api/v1/tools/projects')->to('ToolsProjects#load_projects');
-    $r->put('/tools/api/v1/tools/projects')->to('ToolsProjects#save_projects');
+    $r->get('/tools/api/v1/projects')->to('ToolsProjects#load_projects');
+    $r->put('/tools/api/v1/projects')->to('ToolsProjects#save_projects');
+    $r->get('/tools/api/v1/treelist/:tools_projects_pkey')->to('ToolsTreelist#load_treelist');
 
     $app->log->debug("route loading done");
 }
@@ -172,8 +191,32 @@ CREATE UNIQUE INDEX tools_object_tables_fieldbname_tools_objects_fkey
 
 -- 2 down
 
+-- 3 up
+
+ALTER TABLE tools_version
+    ADD COLUMN name varchar NOT NULL DEFAULT '';
+
+-- 3 down
+
+-- 4 up
+CREATE OR REPLACE VIEW v_tools_projects_workflow_fkey AS
+    SELECT tools_projects.*, workflow_fkey FROM tools_projects JOIN workflow_connections
+	    ON connector_fkey = tools_projects_pkey AND connector = 'tools_projects';
 
 
+CREATE OR REPLACE VIEW v_tools_version_workflow_fkey AS
+    SELECT tools_version.*, workflow_fkey FROM tools_version JOIN workflow_connections
+	    ON tools_projects_fkey = connector_fkey AND connector = 'tools_projects';
+
+-- 4 down
+
+-- 5 up
+CREATE OR REPLACE VIEW v_tools_objects_workflow_fkey AS
+	select tools_objects.*, workflow_fkey from tools_objects JOIN tools_version
+		ON tools_version_fkey = tools_version_pkey
+		JOIN workflow_connections ON connector_fkey = tools_projects_fkey AND connector = 'tools_projects';
+
+-- 5 down
 
 #################### pod generated by Pod::Autopod - keep this line to make pod updates possible ####################
 
